@@ -74,12 +74,20 @@ SS_output <-
   shortrepfile <- repfile
   repfile <- paste(dir,repfile,sep="")
 
-  parfile <- paste(dir,model,".par",sep="")
-  if(!file.exists(parfile)){
+  parfile <- dir(dir,pattern=".par$")
+  if(length(parfile)>1){
+    filetimes <- file.info(paste(dir,parfile,sep="/"))$mtime
+    parfile <- parfile[filetimes==max(filetimes)]
+    if(verbose) cat("Multiple files in directory match pattern *.par\n",
+                    "choosing most recently modified:",parfile,"\n")
+  }    
+  if(length(parfile)==0){
     if(!hidewarn) cat("Some stats skipped because the .par file not found:\n  ",parfile,"\n")
     parfile <- NA
+  }else{
+    parfile <- paste(dir,parfile,sep="/")
   }
-
+  
   # read three rows to get start time and version number from rep file
   if(file.exists(repfile)){
     if(file.info(repfile)$size>0){
@@ -200,15 +208,22 @@ SS_output <-
       stop("Forecase-report.sso file is empty.\n",
            "Change input to 'forecast=FALSE' or rerun model with forecast turned on.")
     }
+    # read the file
     rawforcast1 <- read.table(file=forcastname,col.names=1:ncols,fill=TRUE,quote="",colClasses="character",nrows=-1)
     endyield <- matchfun("MSY_not_calculated",rawforcast1[,1])
     if(is.na(endyield)) yesMSY <- TRUE else yesMSY <- FALSE
     if(yesMSY) endyield <- matchfun("findFmsy",rawforcast1[,10])
-    yieldraw <- rawforcast1[(matchfun("Btarget",rawforcast1[,10])):endyield,]
-    if(SS_versionshort=="SS-V3.20"){
-      yielddat <- yieldraw[c(3:(as.numeric(length(yieldraw[,1])-1))),c(5,8)]
+    # this section move to Report.sso on Jan 6
+    startline <- matchfun("profile",rawforcast1[,11])
+    if(!is.na(startline)){ # before the Jan 6 fix to benchmarks
+      yieldraw <- rawforcast1[(startline+1):endyield,]
     }else{
-      yielddat <- yieldraw[c(3:(as.numeric(length(yieldraw[,1])-1))),c(4,7)]
+      yieldraw <- matchfun2("SPR/YPR_Profile",1,"Dynamic_Bzero",-2)
+    }
+    if(SS_versionshort=="SS-V3.20"){
+      yielddat <- yieldraw[c(2:(as.numeric(length(yieldraw[,1])-1))),c(5,8)]
+    }else{
+      yielddat <- yieldraw[c(2:(as.numeric(length(yieldraw[,1])-1))),c(4,7)]
     }
     colnames(yielddat) <- c("Catch","Depletion")
     yielddat$Catch <- as.numeric(yielddat$Catch)
@@ -219,9 +234,15 @@ SS_output <-
   flush.console()
 
   # check for use of temporary files
-  logfile <- dir(dir,pattern=".log")
+  logfile <- dir(dir,pattern=".log$")
   logfile <- logfile[logfile != "fmin.log"]
-  if(length(logfile)==1 & file.info(paste(dir,logfile,sep='/'))$size>0){
+  if(length(logfile)>1){
+    filetimes <- file.info(paste(dir,logfile,sep="/"))$mtime
+    logfile <- logfile[filetimes==max(filetimes)]
+    if(verbose) cat("Multiple files in directory match pattern *.log\n",
+                    "choosing most recently modified file:",logfile,"\n")
+  }    
+  if(length(logfile)==1 && file.info(paste(dir,logfile,sep='/'))$size>0){
     logfile <- read.table(paste(dir,logfile,sep='/'))[,c(4,6)]
     names(logfile) <- c("TempFile","Size")
     maxtemp <- max(logfile$Size)
@@ -235,7 +256,7 @@ SS_output <-
     }
   }else{
     logfile <- NA
-    if(verbose) cat("Either no non-empty log file in directory or too many files matching pattern *.log\n")
+    if(verbose) cat("No non-empty log file in directory or too many files matching pattern *.log\n")
   }
 
   # read warnings file
@@ -337,8 +358,7 @@ SS_output <-
     rawcompdbase <- read.table(file=compfile, col.names=col.names, fill=TRUE, colClasses="character", skip=compskip, nrows=-1)
     names(rawcompdbase) <- rawcompdbase[1,]
     names(rawcompdbase)[names(rawcompdbase)=="Used?"] <- "Used"
-    
-    compdbase <- rawcompdbase[2:(nrow(rawcompdbase)-3),] # subtract header line and last 2 lines
+    compdbase <- rawcompdbase[2:(nrow(rawcompdbase)-4),] # subtract header line and last 4 lines
     compdbase <- compdbase[compdbase$Obs!="",]
     compdbase[compdbase=="_"] <- NA
     compdbase$Used[is.na(compdbase$Used)] <- "yes"
@@ -610,14 +630,16 @@ SS_output <-
   managementratiolabels <- matchfun2("DERIVED_QUANTITIES",1,"DERIVED_QUANTITIES",3,cols=1:2)
   names(managementratiolabels) <- c("Ratio","Label")
 
-  # time varying parameters
-  MGparmAdj <- matchfun2("MGparm_By_Year_after_adjustments",2,"selparm(Size)_By_Year_after_adjustments",-1)
-  if(nrow(MGparmAdj)>2){
-    MGparmAdj <- MGparmAdj[,MGparmAdj[1,]!=""]
-    names(MGparmAdj) <- c("Yr",parameters$Label[1:(ncol(MGparmAdj)-1)])
+  # time-varying parameters
+  MGparmAdj <- matchfun2("MGparm_By_Year_after_adjustments",1,
+                         "selparm(Size)_By_Year_after_adjustments",-1,header=TRUE)
+  if(nrow(MGparmAdj)>0){
+    for(icol in 1:ncol(MGparmAdj)) MGparmAdj[,icol] <- as.numeric(MGparmAdj[,icol])
   }else{
     MGparmAdj <- NA
   }
+
+  # time-varying size-selectivity parameters
   SelSizeAdj <- matchfun2("selparm(Size)_By_Year_after_adjustments",2,"selparm(Age)_By_Year_after_adjustments",-1)
   if(nrow(SelSizeAdj)>2){
     SelSizeAdj <- SelSizeAdj[,apply(SelSizeAdj,2,emptytest)<1]
@@ -627,6 +649,8 @@ SS_output <-
   }else{
     SelSizeAdj <- NA
   }
+
+  # time-varying age-selectivity parameters
   SelAgeAdj <- matchfun2("selparm(Age)_By_Year_after_adjustments",2,"RECRUITMENT_DIST",-1)
   if(nrow(SelAgeAdj)>2){
     SelAgeAdj <- SelAgeAdj[,apply(SelAgeAdj,2,emptytest)<1]
@@ -897,7 +921,9 @@ SS_output <-
   spr <- spr[spr$Year <= endyr,]
   spr$spr <- spr$SPR
   returndat$sprseries <- spr
-  stats$last_years_sprmetric <- spr$spr[length(spr$spr)]
+  stats$last_years_SPR <- spr$spr[nrow(spr)]
+  stats$SPRratioLabel <- managementratiolabels[1,2]
+  stats$last_years_SPRratio <- spr$SPR_std[nrow(spr)]
 
   if(forecast){
    returndat$equil_yield <- yielddat
@@ -1075,6 +1101,23 @@ SS_output <-
     }
   }
   returndat$catage <- catage
+
+  # Dynamic_Bzero output "with fishery"
+  Dynamic_Bzero1 <- matchfun2("Spawning_Biomass_Report_2",1,"NUMBERS_AT_AGE_Annual_2",-1)
+  # Dynamic_Bzero output "no fishery"
+  Dynamic_Bzero2 <- matchfun2("Spawning_Biomass_Report_1",1,"NUMBERS_AT_AGE_Annual_1",-1)
+  if(Dynamic_Bzero1[[1]][1]=="absent"){
+    Dynamic_Bzero <- NA
+  }else{
+    Dynamic_Bzero <- cbind(Dynamic_Bzero1,Dynamic_Bzero2[,3])
+    names(Dynamic_Bzero) <- c("Yr","Era","SPB","SPB_nofishing")
+    if(nareas==1 & ngpatterns==1){ # for simpler models, do some cleanup
+      Dynamic_Bzero <- Dynamic_Bzero[-(1:2),]
+      for(icol in c(1,3,4)) Dynamic_Bzero[,icol] <- as.numeric(as.character(Dynamic_Bzero[,icol]))
+      names(Dynamic_Bzero) <- c("Yr","Era","SPB","SPB_nofishing")
+    }
+  }
+  returndat$Dynamic_Bzero <- Dynamic_Bzero
   
   # adding stuff to list which gets returned by function
   if(comp){
