@@ -22,6 +22,7 @@ function(
   ncols = 30
   ctl <- read.table(file=ctlfile,col.names=1:ncols,fill=T,
     quote="",colClasses="character",comment.char="", blank.lines.skip=F)
+
   nrows <- nrow(ctl)
   #print(nrows)
   ctl_num <- matrix(NA,nrows,ncols) # copy of ctl converted to numerical values or NA
@@ -39,14 +40,18 @@ function(
   parlines7  <- ctl[num_cnt7==7 & is.na(ctl_num[,8]), ]
   parlines14 <- ctl[num_cnt14==14 & is.na(ctl_num[,15]), ]
 
-  parlines7  <- parlines7[,c(1:7,9)]
-  parlines14 <- parlines14[,c(1:7,16)]
-  namesvec <- c("LO", "HI", "INIT", "PRIOR", "PR_type", "SD", "PHASE", "Label")
+  parlines7  <- parlines7[,c(1:7,8:9)]
+  parlines14 <- parlines14[,c(1:7,15:16)]
+  
+  namesvec <- c("LO", "HI", "INIT", "PRIOR", "PR_type", "SD", "PHASE", "Label", "Label2")
 
   names(parlines7 ) <- namesvec
   names(parlines14) <- namesvec
 
   parlines <- rbind(parlines7,parlines14)
+  parlines$Label[parlines$Label=="#"] <- parlines$Label2[parlines$Label=="#"]
+  parlines <- parlines[,1:8] # dropping the Label2 column
+  
   parlines$Linenum <- as.numeric(rownames(parlines))
   parlines <- parlines[order(parlines$Linenum),]
   for(i in 1:7) parlines[,i] <- as.numeric(parlines[,i])
