@@ -1,5 +1,5 @@
 SSplotBiology <-
-  function(replist, plot=TRUE,print=FALSE,add=FALSE,subplots=1:8,
+  function(replist, plot=TRUE,print=FALSE,add=FALSE,subplots=1:8,seas=1,
            col1="red",col2="blue",
            legendloc="topleft",
            plotdir="default",
@@ -25,7 +25,11 @@ SSplotBiology <-
   # mean weight, maturity, fecundity, spawning output
 
   # get objects from replist
-  growdat      <- replist$endgrowth
+  nseasons     <- replist$nseasons
+  if(!seas %in% 1:nseasons) stop("'seas' input should be within 1:nseasons")
+  if(nseasons>1) labels[6] <- gsub("middle of the year", paste("middle of season",seas), labels[6])
+    
+  growdat      <- replist$endgrowth[replist$endgrowth$Seas==seas,]
   biology      <- replist$biology
   FecType      <- replist$FecType
   FecPar1name  <- replist$FecPar1name
@@ -34,7 +38,6 @@ SSplotBiology <-
   FecPar2      <- replist$FecPar2
   parameters   <- replist$parameters
   nsexes       <- replist$nsexes
-  nseasons     <- replist$nseasons
   mainmorphs   <- replist$mainmorphs
   accuage      <- replist$accuage
   growthseries <- replist$growthseries
@@ -71,7 +74,7 @@ SSplotBiology <-
   if(FecType==2) FecY <- FecPar1*FecX^FecPar2
   if(FecType==3) FecY <- FecPar1*FecX^FecPar2
 
-  # Mid year mean length at age with 95% range of lengths (by sex if applicable)
+  # Midle of season 1 mean length at age with 95% range of lengths (by sex if applicable)
   growdatF <- growdat[growdat$Gender==1 & growdat$Morph==mainmorphs[1],]
   growdatF$Sd_Size <- growdatF$SD_Mid
   growdatF$high <- growdatF$Len_Mid + 1.96*growdatF$Sd_Size
@@ -84,7 +87,7 @@ SSplotBiology <-
     growdatM$low <- growdatM$Len_Mid - 1.96*growdatM$Sd_Size
   }
 
-  gfunc1 <- function(add=FALSE){ # weight
+  gfunc1 <- function(){ # weight
     if(!add){
       ymax <- max(biology$Wt_len_F)
       if(nsexes>1) ymax <- max(ymax, biology$Wt_len_M)
@@ -97,7 +100,7 @@ SSplotBiology <-
       if(!add) legend(legendloc,bty="n", c("Females","Males"), lty=1, col = c(col1,col2))
     }
   }
-  gfunc2 <- function(add=FALSE){ # maturity
+  gfunc2 <- function(){ # maturity
     if(min(biology$Mat_len)<1){ # if length based
       if(!add) plot(x,biology$Mat_len,xlab=labels[1],ylab=labels[3],type="o",col=col1)
       if(add) lines(x,biology$Mat_len,type="o",col=col1)
@@ -107,7 +110,7 @@ SSplotBiology <-
     }
     if(!add) abline(h=0,col="grey")
   }
-  gfunc3 <- function(add=FALSE){ # fecundity
+  gfunc3 <- function(){ # fecundity
     ymax <- 1.1*max(FecY)
     if(!add){
       plot(FecX, FecY, xlab=fec_xlab, ylab=fec_ylab, ylim=c(0,ymax), col=col2, pch=19)
@@ -117,7 +120,7 @@ SSplotBiology <-
       points(FecX, FecY,col=col2,pch=19)
     }
   }
-  gfunc4 <- function(add=FALSE){ # spawning output
+  gfunc4 <- function(){ # spawning output
     if(!add){
       plot(x,biology$Spawn,xlab=labels[1],ylab=labels[5],type="o",col=col1)
       abline(h=0,col="grey")
@@ -132,19 +135,19 @@ SSplotBiology <-
     if(4 %in% subplots) gfunc4()}
   if(print){ # print to PNG files
     if(1 %in% subplots){
-      pngfun(file=paste(plotdir,"01_weightatsize.png",sep=""))
+      pngfun(file=paste(plotdir,"/bio1_weightatsize.png",sep=""))
       gfunc1()
       dev.off()}
     if(2 %in% subplots){
-      pngfun(file=paste(plotdir,"01_maturity.png",sep=""))
+      pngfun(file=paste(plotdir,"/bio2_maturity.png",sep=""))
       gfunc2()
       dev.off()}
     if(3 %in% subplots){
-      pngfun(file=paste(plotdir,"01_fecundity.png",sep=""))
+      pngfun(file=paste(plotdir,"/bio3_fecundity.png",sep=""))
       gfunc3()
       dev.off()}
     if(4 %in% subplots){
-      pngfun(file=paste(plotdir,"01_spawningoutput.png",sep=""))
+      pngfun(file=paste(plotdir,"/bio4_spawningoutput.png",sep=""))
       gfunc4()
       dev.off()}
   }
@@ -155,7 +158,7 @@ SSplotBiology <-
   main <- "Ending year expected growth"
   # if(nseasons > 1){main <- paste(main," season 1",sep="")}
 
-  gfunc5 <- function(add=F) # growth
+  gfunc5 <- function() # growth
   {
     if(!add){
       plot(x,growdatF$Len_Mid,col=col1,lwd=2,ylim=c(0,ymax),type="n",
@@ -176,7 +179,7 @@ SSplotBiology <-
   }
   if(plot & 5 %in% subplots) gfunc5()
   if(print & 5 %in% subplots){
-    pngfun(file=paste(plotdir,"01_sizeatage.png",sep=""))
+    pngfun(file=paste(plotdir,"/bio5_sizeatage.png",sep=""))
     gfunc5()
     dev.off()}
 
@@ -199,7 +202,7 @@ SSplotBiology <-
     }
     if(plot & 6 %in% subplots) mfunc()
     if(print & 6 %in% subplots){
-      pngfun(file=paste(plotdir,"01_natmort.png",sep=""))
+      pngfun(file=paste(plotdir,"/bio6_natmort.png",sep=""))
       mfunc()
       dev.off()}
   }
@@ -233,12 +236,12 @@ SSplotBiology <-
             if(8 %in% subplots) contour(x,y,z,nlevels=12,xlab=labels[2],main=main,cex.main=cex.main,col=ians_contour,lwd=2)}
           if(print){
             if(7 %in% subplots){
-              pngfun(file=paste(plotdir,"02_timevarygrowthsurf_sex",i,".png",sep=""))
+              pngfun(file=paste(plotdir,"/bio7_timevarygrowthsurf_sex",i,".png",sep=""))
               persp(x,y,z,col="white",xlab=labels[2],ylab="",zlab=labels[1],expand=0.5,box=TRUE,main=main,cex.main=cex.main,ticktype="detailed",phi=35,theta=-10)
               dev.off()
             }
             if(8 %in% subplots){
-              pngfun(file=paste(plotdir,"02_timevarygrowthcontour_sex",i,".png",sep=""))
+              pngfun(file=paste(plotdir,"/bio8_timevarygrowthcontour_sex",i,".png",sep=""))
               contour(x,y,z,nlevels=12,xlab=labels[2],main=main,cex.main=cex.main,col=ians_contour,lwd=2)
               dev.off()
             }
