@@ -1,4 +1,5 @@
-plotCI <- function(x,z=x,y=NULL,uiw,liw=uiw,ylo=NULL,yhi=NULL,...,sfrac = 0.01,ymax=NULL)
+plotCI <- function(x,z=x,y=NULL,uiw,liw=uiw,ylo=NULL,yhi=NULL,...,
+                   sfrac = 0.01,ymax=NULL,add=FALSE)
 {
   # Written by Venables; modified for access to ylim and contents
   if(is.list(x))
@@ -11,7 +12,7 @@ plotCI <- function(x,z=x,y=NULL,uiw,liw=uiw,ylo=NULL,yhi=NULL,...,sfrac = 0.01,y
   ui <- y + uiw
   li <- y - liw
   ylim <- range(c(y,ui,li,ylo,yhi,z,ymax))
-  plot(x,y,ylim=ylim,...)
+  if(!add) plot(x,y,ylim=ylim,...) else points(x,y,...)  
   smidge <- diff(par("usr")[1:2]) * sfrac
   segments(x,li,x,ui)
   x2 <- c(x, x)
